@@ -1,7 +1,9 @@
 package Dist::Zilla::Plugin::InsertBlock;
 
-our $DATE = '2021-02-21'; # DATE
-our $VERSION = '0.101'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-04-14'; # DATE
+our $DIST = 'Dist-Zilla-Plugin-InsertBlock'; # DIST
+our $VERSION = '0.102'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,12 +49,19 @@ sub _insert_block {
     if ($content =~ /^=for [ \t]+ BEGIN_BLOCK: [ \t]+ \Q$name\E[ \t]* \R
                      (.*?)
                      ^=for [ \t]+ END_BLOCK: [ \t]+ \Q$name\E/msx) {
-        $self->log(["inserting block from '%s' named %s into '%s'", $file, $name, $target]);
+        $self->log(["inserting block from '%s' named %s into '%s' (=for syntax)", $file, $name, $target]);
+        $block = $1;
+    } elsif ($content =~ /^=over [ \t]+ 11 [ \t]* \R\R
+                          ^=back [ \t]+ BEGIN_BLOCK: [ \t]+ \Q$name\E[ \t]* \R
+                          (.*?)
+                          ^=over [ \t]+ 11 [ \t]* \R\R
+                          ^=back [ \t]+ END_BLOCK:   [ \t]+ \Q$name\E/msx) {
+        $self->log(["inserting block from '%s' named %s into '%s' (=over 11 syntax)", $file, $name, $target]);
         $block = $1;
     } elsif ($content =~ /^\# [ \t]* BEGIN_BLOCK: [ \t]+ \Q$name\E[ \t]* \R
                      (.*?)
                      ^\# [ \t]* END_BLOCK: [ \t]+ \Q$name\E/msx) {
-        $self->log(["inserting block from '%s' named %s into '%s'", $file, $name, $target]);
+        $self->log(["inserting block from '%s' named %s into '%s' (# syntax)", $file, $name, $target]);
         $block = $1;
     } else {
         $self->log_fatal(["can't find block named %s in file '%s'", $name, $file]);
@@ -82,7 +91,7 @@ Dist::Zilla::Plugin::InsertBlock - Insert a block of text from another file
 
 =head1 VERSION
 
-This document describes version 0.101 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-02-21.
+This document describes version 0.102 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-04-14.
 
 =head1 SYNOPSIS
 
@@ -116,6 +125,20 @@ In lib/Foo/Base.pm:
 
  ...
 
+ =head1 METHODS
+
+ =over 11
+
+ =back BEGIN_BLOCK: base_methods
+
+ =head2 meth1
+
+ =head2 meth2
+
+ =over 11
+
+ =back END_BLOCK: base_methods
+
 In lib/Foo/Bar.pm:
 
  ...
@@ -126,12 +149,20 @@ In lib/Foo/Bar.pm:
 
  =head1 ATTRIBUTES
 
- # INSERT_BLOCK: lib/Foo/Bar.pm base_attributes
+ # INSERT_BLOCK: lib/Foo/Base.pm base_attributes
 
  =head2 attr3
 
  ...
 
+ =head1 METHODS
+
+ =INSERT_BLOCK: lib/Foo/Base.pm base_methods
+
+ =head2 meth3
+
+ ...
+
 =head1 DESCRIPTION
 
 This plugin finds C<< # INSERT_BLOCK: <file> <name> >> directive in your
@@ -140,17 +171,30 @@ of text to replace the directive.
 
 Block is marked/defined using either this syntax:
 
+ # BEGIN_BLOCK: Name
+ ...
+ # END_BLOCK: Name
+
+or this (for block inside POD):
+
  =for BEGIN_BLOCK: Name
 
  ...
 
  =for END_BLOCK: Name
 
-or this syntax:
+or this syntax (for block inside POD, in case tools like L<Pod::Weaver> removes
+C<=for> directives):
+
+ =over 11
+
+ =back BEGIN_BLOCK: Name
 
- # BEGIN_BLOCK: Name
  ...
- # END_BLOCK: Name
+
+ =over 11
+
+ =back END_BLOCK: Name
 
 Block name is case-sensitive.
 
