@@ -1,7 +1,9 @@
 package Dist::Zilla::Plugin::InsertBlock::FromModule;
 
-our $DATE = '2021-02-21'; # DATE
-our $VERSION = '0.101'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-04-14'; # DATE
+our $DIST = 'Dist-Zilla-Plugin-InsertBlock'; # DIST
+our $VERSION = '0.102'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,7 +51,7 @@ Dist::Zilla::Plugin::InsertBlock::FromModule - Insert a block of text from anoth
 
 =head1 VERSION
 
-This document describes version 0.101 of Dist::Zilla::Plugin::InsertBlock::FromModule (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-02-21.
+This document describes version 0.102 of Dist::Zilla::Plugin::InsertBlock::FromModule (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-04-14.
 
 =head1 SYNOPSIS
 
